@@ -20,26 +20,18 @@
 #' @noRd
 .BetaCI <- function(object,
                     alpha = NULL) {
-  stopifnot(
-    inherits(
-      object,
-      "betadelta"
-    )
-  )
   if (is.null(alpha)) {
     alpha <- object$args$alpha
   }
   stopifnot(
     all(alpha > 0 & alpha < 1)
   )
-  return(
-    .CIWald(
-      est = object$est,
-      se = sqrt(diag(object$vcov)),
-      theta = 0,
-      alpha = alpha,
-      z = FALSE,
-      df = object$lm_process$df
-    )
+  .CIWald(
+    est = object$est,
+    se = sqrt(diag(object$vcov)),
+    theta = 0,
+    alpha = alpha,
+    z = FALSE,
+    df = object$lm_process$df
   )
 }
