@@ -2,7 +2,7 @@
 #'
 #' @author Ivan Jacob Agaloos Pesigan
 #'
-#' @return Returns a matrix of
+#' @return Prints a matrix of
 #'   standardized regression slopes,
 #'   standard errors,
 #'   test statistics,
@@ -30,19 +30,10 @@ print.betadelta <- function(x,
                             alpha = NULL,
                             digits = 4,
                             ...) {
-  cat("Call:\n")
-  base::print(x$call)
-  cat(
-    "\nStandardized regression slopes with",
-    toupper(x$args$type),
-    "standard errors:\n"
-  )
-  base::print(
-    round(
-      .BetaCI(
-        object = x,
-        alpha = alpha
-      ),
+  print.summary.betadelta(
+    summary.betadelta(
+      object = x,
+      alpha = alpha,
       digits = digits
     )
   )
@@ -80,6 +71,47 @@ summary.betadelta <- function(object,
                               alpha = NULL,
                               digits = 4,
                               ...) {
+  ci <- .BetaCI(
+    object = object,
+    alpha = alpha
+  )
+  print_summary <- round(
+    x = ci,
+    digits = digits
+  )
+  attr(
+    x = ci,
+    which = "fit"
+  ) <- object
+  attr(
+    x = ci,
+    which = "print_summary"
+  ) <- print_summary
+  attr(
+    x = ci,
+    which = "alpha"
+  ) <- alpha
+  attr(
+    x = ci,
+    which = "digits"
+  ) <- digits
+  class(ci) <- "summary.betadelta"
+  ci
+}
+
+#' @noRd
+#' @keywords internal
+#' @exportS3Method print summary.betadelta
+print.summary.betadelta <- function(x,
+                                    ...) {
+  print_summary <- attr(
+    x = x,
+    which = "print_summary"
+  )
+  object <- attr(
+    x = x,
+    which = "fit"
+  )
   cat("Call:\n")
   base::print(object$call)
   cat(
@@ -87,15 +119,8 @@ summary.betadelta <- function(object,
     toupper(object$args$type),
     "standard errors:\n"
   )
-  return(
-    round(
-      .BetaCI(
-        object = object,
-        alpha = alpha
-      ),
-      digits = digits
-    )
-  )
+  print(print_summary)
+  invisible(x)
 }
 
 #' Sampling Covariance Matrix of the Standardized Regression Slopes
@@ -118,9 +143,7 @@ summary.betadelta <- function(object,
 #' @export
 vcov.betadelta <- function(object,
                            ...) {
-  return(
-    object$vcov
-  )
+  object$vcov
 }
 
 #' Standardized Regression Slopes
@@ -141,9 +164,7 @@ vcov.betadelta <- function(object,
 #' @export
 coef.betadelta <- function(object,
                            ...) {
-  return(
-    object$est
-  )
+  object$est
 }
 
 #' Confidence Intervals for Standardized Regression Slopes
@@ -187,7 +208,5 @@ confint.betadelta <- function(object,
     x = varnames
   )
   colnames(ci) <- varnames
-  return(
-    ci
-  )
+  ci
 }
