@@ -13,18 +13,18 @@
 #' @family Wald Confidence Intervals Functions
 #' @keywords wald alpha internal
 #' @noRd
-.ProbsofAlpha <- function(alpha = c(
-                            0.05,
-                            0.01,
-                            0.001
-                          )) {
+.ProbsofAlpha <- function(
+  alpha = c(
+    0.05,
+    0.01,
+    0.001
+  )
+) {
   lower <- 0.5 * alpha
-  return(
-    sort(
-      c(
-        lower,
-        1 - lower
-      )
+  sort(
+    c(
+      lower,
+      1 - lower
     )
   )
 }
